@@ -99,8 +99,7 @@ class Wsdl(WsdlBase):
                                 brief=('os_install_uefi',),
                                 expert=('cl_uuid_set',
                                         'os_install_mbr',
-                                        'os_install_uefi',
-                                        'os_install_kernel_scheduler')),
+                                        'os_install_uefi')),
             lambda group: group(_("Network settings"),
                                 normal=(
                                     'os_install_net_conf',
@@ -214,7 +213,6 @@ class Wsdl(WsdlBase):
                                     normal=(
                                         'os_install_mbr',
                                         'os_install_uefi',
-                                        'os_install_kernel_scheduler',
                                         'os_install_grub_terminal',
                                         'cl_grub_pwd',
                                         'cl_grub_remove_pwd_set',
